@@ -15,6 +15,12 @@ if test -z "${1}"; then
     exit 1
 fi
 
+# pekwm configuration directory, setup by pekwm but use this to ensure
+# that the script will run properly without running from pekwm.
+if test -z "$PEKWM_CONFIG_PATH"; then
+    PEKWM_CONFIG_PATH="$HOME/.pekwm"
+fi
+
 if test -z "${2}"; then
     theme_dir="${1}"
 
@@ -30,8 +36,8 @@ if test -z "${2}"; then
             if test -d "${theme_name}"; then
                 theme_path="${theme_dir}/${theme_name}"
                 echo "Entry = \"${theme_name}\" { Actions = \"Exec ${0} ${1} ${theme_path}\" }"
-                for theme_variant in `ls ${theme_path}/theme-* 2>/dev/null | /bin/grep -v '~'`; do
-                    variant=`basename ${theme_variant} | /bin/sed 's/theme-//'`
+                for theme_variant in `ls ${theme_path}/theme-* 2>/dev/null | /usr/bin/grep -v '~'`; do
+                    variant=`basename ${theme_variant} | /usr/bin/sed 's/theme-//'`
                     echo "Entry = \"${theme_name} (${variant})\" { Actions = \"Exec ${0} ${1} ${theme_path} ${variant}\" }"
                 done
             fi
@@ -49,7 +55,7 @@ else
         exit 1;
     fi
 
-    theme=`echo "${2}" | /bin/sed -e "s@^${HOME}@~@" | /bin/sed -e 's@\/@\\\/@g'`
+    theme=`echo "${2}" | /usr/bin/sed -e "s@^${HOME}@~@" | /usr/bin/sed -e 's@\/@\\\/@g'`
     variant="${3}"
 
     # Get temporary file, not all platforms have mktemp though
@@ -67,14 +73,14 @@ else
     qq='\"'
     text='[Tt][Hh][Ee][Mm][Ee]'
 
-    /bin/sed -e "/^\([^#]*\)ThemeVariant/d" \
+    /usr/bin/sed -e "/^\([^#]*\)ThemeVariant/d" \
      -e "s/^\([^#]*\)$text$wspc=$wspc$qq[^$qq]*$qq/\1Theme\2=\3$qq${theme}$qq@    ThemeVariant = $qq${variant}$qq/" \
      "${PEKWM_CONFIG_FILE}" \
      | tr '@' '\n' > "${tmp_file}"
     mv "${tmp_file}" "${PEKWM_CONFIG_FILE}"
 
     # Reload pekwm
-    kill -HUP `xprop -root _NET_WM_PID | /usr/bin/gawk '/_NET_WM_PID/ { print $3 }'`
+    kill -HUP `xprop -root _NET_WM_PID | /usr/bin/awk '/_NET_WM_PID/ { print $3 }'`
 fi
 
 exit 0
